##############################################################

## DID MULTICULRUAL AMERICA RESULT FROM A MISTAKE?
## THE 1965 IMMIGRATION ACT AND EVIDENCE FROM ROLL CALL VOTES

## by Jack Chin & Doug Spencer
## Last updated: March 1, 2015

##############################################################

## Library required packages
library(foreign)
library(pscl)
library(wnominate)
library(ggplot2)
library(stringr)
library(reshape)
library(grid)

## Set working directory
setwd('chin_spencer_replication/')

## Download roll call data
# http://voteview.com/senate88.htm; http://voteview.com/house88.htm
# http://voteview.com/senate89.htm; http://voteview.com/house89.htm

## Read in data and remove Presidential votes
h88 <- read.dta('data/hou88kh.dta'); h88 <- h88[h88$id<99900,]
s88 <- read.dta('data/sen88kh.dta'); s88 <- s88[s88$id<99900,]

h89 <- read.dta('data/hou89kh.dta'); h89 <- h89[h89$id<99900,]
s89 <- read.dta('data/sen89kh.dta'); s89 <- s89[s89$id<99900,]

##############################################################

## Variables from the codebooks:
# 88th House -- ftp://voteview.com/dtl/88.dtl
# 89th House -- ftp://voteview.com/dtl/89.dtl
# 88th Senate -- ftp://voteview.com/dtl/88s.dtl
# 89th Senate -- ftp://voteview.com/dtl/89s.dtl

##############################################################

##  TABLE 1: Overview of Roll Call Votes

#   Values:
#   1 = yea, 6 = nay
#   100 = Democrat, 200 = Republican

#   (A) HOUSE OF REPRESENTATIVES

# Civil Rights Act
table(h88$V128[h88$V128==1 | h88$V128==6], h88$party[h88$V128==1 | h88$V128==6])
# Senate version
table(h88$V182[h88$V182==1 | h88$V182==6], h88$party[h88$V182==1 | h88$V182==6])

# Voting Rights Act
table(h89$V87[h89$V87==1 | h89$V87==6], h89$party[h89$V87==1 | h89$V87==6])
# Conference version
table(h89$V107[h89$V107==1 | h89$V107==6], h89$party[h89$V107==1 | h89$V107==6])

# Immigration and Nationality Act
table(h89$V125[h89$V125==1 | h89$V125==6], h89$party[h89$V125==1 | h89$V125==6])
# Senate version
table(h89$V177[h89$V177==1 | h89$V177==6], h89$party[h89$V177==1 | h89$V177==6])

#   (B) SENATE

# Civil Rights Act
table(s88$V288[s88$V288==1 | s88$V288==6], s88$party[s88$V288==1 | s88$V288==6])
# Cloture vote
table(s88$V302[s88$V302==1 | s88$V302==6], s88$party[s88$V302==1 | s88$V302==6])
# Adopt substitute for HR 7152
table(s88$V407[s88$V407==1 | s88$V407==6], s88$party[s88$V407==1 | s88$V407==6])
# Final version
table(s88$V409[s88$V409==1 | s88$V409==6], s88$party[s88$V409==1 | s88$V409==6])

# Voting Rights Act
table(s89$V77[s89$V77==1 | s89$V77==6], s89$party[s89$V77==1 | s89$V77==6])
# Cloture vote
table(s89$V67[s89$V67==1 | s89$V67==6], s89$party[s89$V67==1 | s89$V67==6])
# Conference version
table(s89$V178[s89$V178==1 | s89$V178==6], s89$party[s89$V178==1 | s89$V178==6])

# Immigration and Nationality Act
table(s89$V232[s89$V232==1 | s89$V232==6], s89$party[s89$V232==1 | s89$V232==6])

##############################################################

## TABLE 2: Members of Congress that voted for more than one bill

cra.h <- h88[,c(1:9)]; cra.h$cra <- h88$V182
cra.s <- s88[,c(1:9)]; cra.s$cra <- s88$V409

oth.h <- h89[,c(1:9)]
  oth.h$vra <- h89$V107
  oth.h$ina <- h89$V177
oth.s <- s89[,c(1:9)]
  oth.s$vra <- s89$V178
  oth.s$ina <- s89$V232

all.h <- merge(cra.h[,c(2,10)], oth.h, all=T)
all.s <- merge(cra.s[,c(2,10)], oth.s, all=T)

# HOUSE
table(all.h$cra)[2] # CRA = 289
table(all.h$cra[!is.na(all.h$vra)])[2] # Adj. CRA = 239
table(all.h$vra)[2] # VRA = 328
table(all.h$ina)[2] # INA = 320
  table(all.h$cra, all.h$vra)[2,2] # CRA/VRA = 221
  table(all.h$cra, all.h$ina)[2,2] # CRA/INA = 207
  table(all.h$vra, all.h$ina)[2,2] # VRA/INA = 283

# SENATE
table(all.s$cra)[2] # CRA = 73
table(all.s$cra[!is.na(all.s$vra)])[1] # Adj. CRA = 68
table(all.s$vra)[2] # VRA = 79
table(all.s$ina)[2] # INA = 76
  table(all.s$cra, all.s$vra)[2,2] # CRA/VRA = 66
  table(all.s$cra, all.s$ina)[2,2] # CRA/INA = 62
  table(all.s$vra, all.s$ina)[2,2] # VRA/INA = 72

##############################################################

## FIGURE 1: Roll Call Votes in the 89th Congress, ranked by
##           percent of overlapping support for the 1965 INA

df <- h89[,-c(1:9)]
sdf <- s89[,-c(1:9)]

df.out <- array(NA,c(length(names(df)),3))
dimnames(df.out) <- list(c(names(df)), c('cor', 'unan', 'pct.nay'))
sdf.out <- array(NA,c(length(names(sdf)),3))
dimnames(sdf.out) <- list(c(names(sdf)), c('cor', 'unan', 'pct.nay'))

for (i in 1:dim(df)[2]){
  bill <- ifelse(df[,i]==1, 1, ifelse(df[,i]==6, 2, NA))
  ina <- ifelse(df$V177==1, 1, ifelse(df$V177==6, 2, NA))
  df.out[i,1] <- (table(bill, ina)[1])/320
  df.out[i,2] <- table(bill)[2]
  df.out[i,3] <- table(bill)[2] / sum(table(bill))
}

for (j in 1:dim(sdf)[2]){
  bill <- ifelse(sdf[,j]==1, 1, ifelse(sdf[,j]==6, 2, NA))
  ina <- ifelse(sdf$V232==1, 1, ifelse(sdf$V232==6, 2, NA))
  sdf.out[j,1] <- (table(bill, ina)[1])/76
  sdf.out[j,2] <- table(bill)[2]
  sdf.out[j,3] <- table(bill)[2] / sum(table(bill))
}

df.plot <- as.data.frame(df.out); df.plot$rc <- row.names(df.out)
sdf.plot <- as.data.frame(sdf.out); sdf.plot$rc <- row.names(sdf.out)

## Raw data
df.raw <- df.plot[order(df.plot$cor, decreasing=T),]; df.raw$num <- 1:dim(df.raw)[1]
sdf.raw <- sdf.plot[order(sdf.plot$cor, decreasing=T),]; sdf.raw$num <- 1:dim(sdf.raw)[1]

## Drop unanimous votes (and final INA vote as reference)
df.plot <- subset(df.raw, df.raw$pct.nay >= 0.025 & df.raw$rc!='V177')
sdf.plot <- subset(sdf.raw, sdf.raw$pct.nay >= 0.025 & sdf.raw$rc!='V232')

df.plot$trunc.num <- 1:dim(df.plot)[1]
sdf.plot$trunc.num <- 1:dim(sdf.plot)[1]

## Add extra empty bills for spacing (so extreme points aren't cut off)
df.plot$color <- 'black'
high1 <- c(1, 0,0,'high1', 0,0, 'white')
high2 <- c(1, 0,0,'high2', 0,0, 'white')
high3 <- c(1, 0,0,'high3', 0,0, 'white')
high4 <- c(1, 0,0,'high4', 0,0, 'white')

low1 <- c(0, 0,0,'low1', 0,0, 'white')
low2 <- c(0, 0,0,'low2', 0,0, 'white')
low3 <- c(0, 0,0,'low3', 0,0, 'white')
low4 <- c(0, 0,0,'low4', 0,0, 'white')

df.plot <- rbind(df.plot, high1, high2, high3, high4, low1, low2, low3, low4)
df.plot$cor <- as.numeric(df.plot$cor)
df.plot$rc.plot <- as.factor(reorder(df.plot$rc, df.plot$cor))

###

sdf.plot$color <- 'black'
high1 <- c(1, 0,0,'high1', 0,0, 'white')
high2 <- c(1, 0,0,'high2', 0,0, 'white')
high3 <- c(1, 0,0,'high3', 0,0, 'white')
high4 <- c(1, 0,0,'high4', 0,0, 'white')

low1 <- c(0, 0,0,'low1', 0,0, 'white')
low2 <- c(0, 0,0,'low2', 0,0, 'white')
low3 <- c(0, 0,0,'low3', 0,0, 'white')
low4 <- c(0, 0,0,'low4', 0,0, 'white')

sdf.plot <- rbind(sdf.plot, high1, high2, high3, high4, low1, low2, low3, low4)
sdf.plot$cor <- as.numeric(sdf.plot$cor)
sdf.plot$rc.plot <- as.factor(reorder(sdf.plot$rc, sdf.plot$cor))

df.plot$color[df.plot$rc=='V107'] <- 'red' # VRA (final)
df.plot$color[df.plot$rc=='V323'] <- 'red' # FAA
df.plot$color[df.plot$rc=='V392'] <- 'red' # FITA
df.plot$color[df.plot$rc=='V87'] <- 'red' # VRA (initial)
df.plot$color[df.plot$rc=='V290'] <- 'red' # CRA amendments
df.plot$color[df.plot$rc=='V125'] <- 'red' # INA amendments

sdf.plot$color[sdf.plot$rc=='V178'] <- 'red' # VRA (final)
sdf.plot$color[sdf.plot$rc=='V77'] <- 'red' # VRA (Mans-Dirk)
sdf.plot$color[sdf.plot$rc=='V78'] <- 'red' # VRA (initial)
sdf.plot$color[sdf.plot$rc=='V67'] <- 'red' # VRA (cloture)
sdf.plot$color[sdf.plot$rc=='V445'] <- 'red' # FAA
sdf.plot$color[sdf.plot$rc=='V497'] <- 'red' # FITA

### PLOT FOR HOUSE

house.labels <- data.frame(
  bill=c(255,230,160,260,250,255),
  vbill=c('V107', 'V323', 'V392', 'V87', 'V290', 'V125'),
  cor1=c(df.plot$cor[df.plot$rc=='V107'], df.plot$cor[df.plot$rc=='V323'],
         df.plot$cor[df.plot$rc=='V392'], df.plot$cor[df.plot$rc=='V87'],
         df.plot$cor[df.plot$rc=='V290'], df.plot$cor[df.plot$rc=='V125']),
  cor2=c(df.plot$cor[df.plot$rc=='V107']-0.035, df.plot$cor[df.plot$rc=='V323'],
         df.plot$cor[df.plot$rc=='V392'], df.plot$cor[df.plot$rc=='V87']+0.035,
         df.plot$cor[df.plot$rc=='V290']+0.01, df.plot$cor[df.plot$rc=='V125']-0.01),
  label=c('VRA (final)', 'Foreign Assistance Act', 'Foreign Investors Tax Act', 'VRA (initial)', 'CRA amendments', 'INA amendments'),
  x=c(270,195,125,275,275,280),
  xend=c(295,180,110,305,300,297))

house.plot <- qplot(rc.plot, cor*100, data=df.plot, col=as.factor(df.plot$color))+ xlab('') + ylab('Percent of overlapping support for INA') +
  theme(panel.background=element_rect(fill = 'white', colour = 'black')) +
  scale_color_manual(values=c('black', 'red', 'white'), guide='none') +
  theme(axis.text.x=element_text(colour='white'), axis.text.y=element_text(size=10)) +
  annotate('text', label=house.labels$label, x=house.labels$bill, y=house.labels$cor2*100, size=2.25) +
  geom_point(data=house.labels, mapping=aes(x=vbill, y=cor1*100, color='red')) +
  geom_segment(aes(x=house.labels[1,6], y=house.labels[1,4]*100, xend=house.labels[1,7], yend=house.labels[1,3]*100, col='black'), size=0.001,
               arrow = arrow(length = unit(1, 'mm'))) +
  geom_segment(aes(x=house.labels[2,6], y=house.labels[2,4]*100, xend=house.labels[2,7], yend=house.labels[2,3]*100, col='black'), size=0.001,
               arrow = arrow(length = unit(1, 'mm'))) +
  geom_segment(aes(x=house.labels[3,6], y=house.labels[3,4]*100, xend=house.labels[3,7], yend=house.labels[3,3]*100, col='black'), size=0.001,
               arrow = arrow(length = unit(1, 'mm'))) +
  geom_segment(aes(x=house.labels[4,6], y=house.labels[4,4]*100, xend=house.labels[4,7], yend=house.labels[4,3]*100, col='black'), size=0.001,
               arrow = arrow(length = unit(1, 'mm'))) +
  geom_segment(aes(x=house.labels[5,6], y=house.labels[5,4]*100, xend=house.labels[5,7], yend=house.labels[5,3]*100, col='black'), size=0.001,
               arrow = arrow(length = unit(1, 'mm'))) +
  geom_segment(aes(x=house.labels[6,6], y=house.labels[6,4]*100, xend=house.labels[6,7], yend=house.labels[6,3]*100, col='black'), size=0.001,
               arrow = arrow(length = unit(1, 'mm'))) +
  ggtitle('(A) House')

pdf('figures/figure_1_house.pdf', width=5.5, height=4)
print(house.plot)
dev.off()

### PLOT FOR SENATE

senate.labels <- data.frame(
  bill=c(375,380,385,380,325,280),
  vbill=c('V178', 'V77', 'V78', 'V67', 'V445', 'V497'),
  cor1=c(sdf.plot$cor[sdf.plot$rc=='V178'], sdf.plot$cor[sdf.plot$rc=='V77'],
         sdf.plot$cor[sdf.plot$rc=='V78']-0.01, sdf.plot$cor[sdf.plot$rc=='V67'],
         sdf.plot$cor[sdf.plot$rc=='V445'], sdf.plot$cor[sdf.plot$rc=='V497']),
  cor2=c(sdf.plot$cor[sdf.plot$rc=='V178'], sdf.plot$cor[sdf.plot$rc=='V77'],
         sdf.plot$cor[sdf.plot$rc=='V78']-0.04, sdf.plot$cor[sdf.plot$rc=='V67']-0.04,
         sdf.plot$cor[sdf.plot$rc=='V445'], sdf.plot$cor[sdf.plot$rc=='V497']),
  label=c('Voting Rights Act (final)', 'VRA (Mans-Dirks)', 'VRA (initial)', 'VRA (cloture)', 'Foreign Assistance Act', 'Foreign Investors Tax Act'),
  x=c(420,415,410,410,280,230),
  xend=c(442,440,440,435,255,195))

senate.plot <- qplot(rc.plot, cor*100, data=sdf.plot, col=as.factor(sdf.plot$color)) + xlab('') + ylab('Percent of overlapping support for INA') +
  theme(panel.background=element_rect(fill = 'white', colour = 'black')) +
  scale_color_manual(values=c('black', 'red', 'white'), guide='none') +
  theme(axis.text.x=element_text(colour='white'), axis.text.y=element_text(size=10)) +
  annotate('text', label=senate.labels$label, x=senate.labels$bill, y=senate.labels$cor2*100, size=2.25) +
  geom_point(data=senate.labels, mapping=aes(x=vbill, y=cor1*100, color='red')) +
  geom_segment(aes(x=senate.labels[1,6], y=senate.labels[1,4]*100, xend=senate.labels[1,7], yend=senate.labels[1,3]*100, col='black'), size=0.001,
               arrow = arrow(length = unit(1, 'mm'))) +
  geom_segment(aes(x=senate.labels[2,6], y=senate.labels[2,4]*100, xend=senate.labels[2,7], yend=senate.labels[2,3]*100, col='black'), size=0.001,
               arrow = arrow(length = unit(1, 'mm'))) +
  geom_segment(aes(x=senate.labels[3,6], y=senate.labels[3,4]*100, xend=senate.labels[3,7], yend=senate.labels[3,3]*100, col='black'), size=0.001,
               arrow = arrow(length = unit(1, 'mm'))) +
  geom_segment(aes(x=senate.labels[4,6], y=senate.labels[4,4]*100, xend=senate.labels[4,7], yend=senate.labels[4,3]*100, col='black'), size=0.001,
               arrow = arrow(length = unit(1, 'mm'))) +
  geom_segment(aes(x=senate.labels[5,6], y=senate.labels[5,4]*100, xend=senate.labels[5,7], yend=senate.labels[5,3]*100, col='black'), size=0.001,
               arrow = arrow(length = unit(1, 'mm'))) +
  geom_segment(aes(x=senate.labels[6,6], y=senate.labels[6,4]*100, xend=senate.labels[6,7], yend=senate.labels[6,3]*100, col='black'), size=0.001,
               arrow = arrow(length = unit(1, 'mm'))) +
  ggtitle('(B) Senate')

pdf('figures/figure_1_senate.pdf', width=5.5, height=4)
print(senate.plot)
dev.off()

##############################################################

## FIGURE 2: Two-dimensional scaled measure of ideology for
#            each legislator in the 88th and 89th Congresses

## DW-NOMINATE scores (available at: http://voteview.com/dwnominate.asp)
#   
dw <- read.dta('data/HL01112D21_PRES_BSSE_9.DTA')
dws <- read.dta('data/SL01112D21_BSSE_9.DTA')

dw <- subset(dw, dw$cong==88 | dw$cong==89)
dws <- subset(dws, dws$cong==88 | dws$cong==89)

## Merge in CRA, VRA, and INA votes
cra.h <- h88[,c(2,191)]; names(cra.h) <- c('id', 'vote')
cra.s <- s88[,c(2,418)]; names(cra.s) <- c('id', 'vote')
vra.h <- h89[,c(2,116)]; names(vra.h) <- c('id', 'vote')
vra.s <- s89[,c(2,187)]; names(vra.s) <- c('id', 'vote')
ina.h <- h89[,c(2,186)]; names(ina.h) <- c('id', 'vote')
ina.s <- s89[,c(2,241)]; names(ina.s) <- c('id', 'vote')

# House
merge.1 <- merge(dw, cra.h, by.x='idno', by.y='id', all.x=F, all.y=T)
merge.1 <- merge.1[!duplicated(merge.1$idno),] # 'idno' for dw
  merge.1$bill='Civil Rights Act'
merge.2 <- merge(dw, vra.h, by.x='idno', by.y='id', all.x==F, all.y=T)
merge.2 <- merge.2[!duplicated(merge.2$idno),] #'idno' for dw
  merge.2$bill='Voting Rights Act'
merge.3 <- merge(dw, ina.h, by.x='idno', by.y='id', all.x=F, all.y=T)
merge.3 <- merge.3[!duplicated(merge.3$idno),]
  merge.3$bill='Immigration Act'

id.house <- rbind(merge.1, merge.2, merge.3)
id.house$house <- 'House'

## Senate
smerge.1 <- merge(dws, cra.s, by.x='idno', by.y='id', all.x=F, all.y=T)
smerge.1 <- smerge.1[!duplicated(smerge.1$idno),] # 'idno' for dws
  smerge.1$bill='Civil Rights Act'
smerge.2 <- merge(dws, vra.s, by.x='idno', by.y='id', all.x=F, all.y=T)
smerge.2 <- smerge.2[!duplicated(smerge.2$idno),]
  smerge.2$bill='Voting Rights Act'
smerge.3 <- merge(dws, ina.s, by.x='idno', by.y='id', all.x=F, all.y=T)
smerge.3 <- smerge.3[!duplicated(smerge.3$idno),]
  smerge.3$bill='Immigration Act'

id.sen <- rbind(smerge.1, smerge.2, smerge.3)
id.sen$house <- 'Senate'

## Concatenate House and Senate data
df.plot <- rbind(id.house, id.sen)
df.plot$vote <- ifelse(df.plot$vote==1, 1, ifelse(df.plot$vote==6, 2, NA))
df.plot$vote[df.plot$name=='TOWER' & df.plot$bill=='Voting Rights Act'] <- 2

## Now for the plot (dwnom1 and dwnom2)
plot <- qplot(dwnom1, dwnom2, data=df.plot, col=as.factor(vote), shape=as.factor(party)) +
  scale_color_manual('Votes', values=c('gray', 'red'), labels=c('Yea', 'Nay')) +
  scale_shape_manual('Party', values=c(19, 4), labels=c('Dem', 'Repub')) +
  facet_grid(house~bill) + theme_bw() + xlab('1st dimension (general left-right politics)') + ylab('2nd dimension (racial politics)')

pdf('figures/figure_2.pdf', width=7.5, height=4.5)
print(plot)
dev.off()

##############################################################
##############################################################

## For text on page 19 (pct vote no with dwnom2 above 0.5)
quart.1 <- NA
quart.1[df.plot$dwnom1 < -0.5] <- 1
quart.1[df.plot$dwnom1 >= -0.5 & df.plot$dwnom1 < 0] <- 2
quart.1[df.plot$dwnom1 >= 0 & df.plot$dwnom1 <= 0.5] <- 3
quart.1[df.plot$dwnom1 > 0.5] <- 4

quart.2 <- NA
quart.2[df.plot$dwnom2 < -0.5] <- 1
quart.2[df.plot$dwnom2 >= -0.5 & df.plot$dwnom2 < 0] <- 2
quart.2[df.plot$dwnom2 >= 0 & df.plot$dwnom2 <= 0.5] <- 3
quart.2[df.plot$dwnom2 > 0.5] <- 4

df.plot$vote.no <- ifelse(df.plot$vote==2, 1, 0)
df.plot$second.high <- ifelse(df.plot$dwnom2 > 0.5, 1, 0)
aggregate(vote.no ~ second.high + bill + house, data=df.plot, FUN=mean)

## Footnote 72:
## Identify the 10 Senators that voted against cloture but for the VRA
df.plot$vclo <- 1
df.plot$vclo[df.plot$name=='BENNETT' & df.plot$statenm=='UTAH' & df.plot$bill=='Voting Rights Act'] <- 2
df.plot$vclo[df.plot$name=='BIBLE' & df.plot$statenm=='NEVADA' & df.plot$bill=='Voting Rights Act'] <- 2
df.plot$vclo[df.plot$name=='CANNON' & df.plot$statenm=='NEVADA' & df.plot$bill=='Voting Rights Act'] <- 2
df.plot$vclo[df.plot$name=='HICKENLOOPE' & df.plot$statenm=='IOWA' & df.plot$bill=='Voting Rights Act'] <- 2
df.plot$vclo[df.plot$name=='SMATHERS' & df.plot$statenm=='FLORIDA' & df.plot$bill=='Voting Rights Act'] <- 2
df.plot$vclo[df.plot$name=='FANNIN' & df.plot$statenm=='ARIZONA' & df.plot$bill=='Voting Rights Act'] <- 2
df.plot$vclo[df.plot$name=='MILLER' & df.plot$statenm=='IOWA' & df.plot$bill=='Voting Rights Act'] <- 2
df.plot$vclo[df.plot$name=='MURPHY' & df.plot$statenm=='CALIFOR' & df.plot$bill=='Voting Rights Act'] <- 2
df.plot$vclo[df.plot$name=='SIMPSON' & df.plot$statenm=='WYOMING' & df.plot$bill=='Voting Rights Act'] <- 2
df.plot$vclo[df.plot$name=='YOUNG  M.R.' & df.plot$statenm=='NORTH D' & df.plot$bill=='Voting Rights Act'] <- 2

df.plot$vra.clo <- df.plot$vote
df.plot$vra.clo[df.plot$house=='Senate' & df.plot$bill=='Voting Rights Act' & df.plot$vclo==2] <- 3

## Text for footnote
aggregate(dwnom2~vra.clo, data=df.plot[df.plot$house=='Senate' & df.plot$bill=='Voting Rights Act',], FUN=mean)

##############################################################

## Clear environment
rm(list=ls())

##############################################################
## END OF FILE
##############################################################